@@ -3,16 +3,19 @@ package LWP::Simple::REST;
 use strict;
 use warnings FATAL => 'all';
 use Data::Structure::Util qw( unbless );
+use Data::Dumper;
 
 use Exporter qw( import );
 our @EXPORT_OK = qw/
     http_get
     http_post
+    http_put
     http_delete
     http_head
     http_upload
     json_get
     json_post
+    json_put
     json_head
 /;
 
@@ -21,7 +24,7 @@ use HTTP::Request;
 use Try::Tiny;
 use JSON;
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 my $user_agent = "LWP::Simple::REST";
 
@@ -56,6 +59,19 @@ sub http_post {
     return $response->content;
 }
 
+sub http_put {
+    my ( $url, $arguments ) = @_;
+
+    my $ua = LWP::UserAgent->new;
+    $ua->agent($user_agent);
+
+    my $response = $ua->put( $url,
+        $arguments,
+    );
+
+    return $response->content;
+}
+
 sub upload_post {
     my ( $url, $json, $filename ) = @_;
 
@@ -106,7 +122,7 @@ sub http_head {
     my $parameters_for_url = join "&", @parameters;
     my $response = $ua->head( $url . "?$parameters_for_url" );
 
-    return unbless($response->headers);
+    return $response->headers;
 
 }
 
@@ -128,6 +144,19 @@ sub json_post {
     return decode_json $response->content;
 }
 
+sub json_put {
+    my ( $url, $arguments ) = @_;
+
+    my $ua = LWP::UserAgent->new;
+    $ua->agent($user_agent);
+
+    my $response = $ua->put( $url,
+        $arguments,
+    );
+
+    return decode_json $response->content;
+}
+
 sub json_get {
     my ( $url, $arguments ) = @_;
 
